"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    Object.defineProperty(o, k2, { enumerable: true, get: function() { return m[k]; } });
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __exportStar = (this && this.__exportStar) || function(m, exports) {
    for (var p in m) if (p !== "default" && !Object.prototype.hasOwnProperty.call(exports, p)) __createBinding(exports, m, p);
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.run = void 0;
const utils_package_1 = require("@goldstack/utils-package");
const utils_cli_1 = require("@goldstack/utils-cli");
const utils_terraform_1 = require("@goldstack/utils-terraform");
const templateLambdaApiDeploy_1 = require("./templateLambdaApiDeploy");
const utils_terraform_aws_1 = require("@goldstack/utils-terraform-aws");
const utils_package_config_1 = require("@goldstack/utils-package-config");
const utils_package_2 = require("@goldstack/utils-package");
__exportStar(require("./types/LambdaApiPackage"), exports);
const yargs_1 = __importDefault(require("yargs"));
const fs_1 = __importDefault(require("fs"));
const utils_aws_lambda_1 = require("@goldstack/utils-aws-lambda");
const generateLambdaConfig_1 = require("./generateLambdaConfig");
const templateLambdaConsts_1 = require("./templateLambdaConsts");
const templateLambdaApiBuild_1 = require("./templateLambdaApiBuild");
const run = async (args) => {
    await (0, utils_cli_1.wrapCli)(async () => {
        const argv = (0, utils_package_1.buildCli)({
            yargs: yargs_1.default,
            deployCommands: (0, utils_package_1.buildDeployCommands)(),
            infraCommands: (0, utils_terraform_1.infraCommands)(),
        })
            .command('build [deployment]', 'Build all lambdas', () => {
            return yargs_1.default.positional('deployment', {
                type: 'string',
                describe: 'Name of the deployment this command should be applied to',
                default: '',
            });
        })
            .help().argv;
        const packageConfig = new utils_package_config_1.PackageConfig({
            packagePath: './',
        });
        const config = packageConfig.getConfig();
        // update routes
        if (!fs_1.default.existsSync('./src/routes')) {
            throw new Error('Please specify lambda function handlers in ./src/routes so that API Gateway route configuration can be generated.');
        }
        const lambdaRoutes = (0, utils_aws_lambda_1.readLambdaConfig)(templateLambdaConsts_1.defaultRoutesPath);
        config.deployments = config.deployments.map((e) => {
            const lambdasConfigs = (0, generateLambdaConfig_1.generateLambdaConfig)(e, lambdaRoutes);
            e.configuration.lambdas = lambdasConfigs;
            (0, generateLambdaConfig_1.validateDeployment)(e.configuration.lambdas);
            return e;
        });
        (0, utils_package_2.writePackageConfig)(config);
        const command = argv._[0];
        const [, , , ...opArgs] = args;
        if (command === 'infra') {
            await (0, utils_terraform_aws_1.terraformAwsCli)(opArgs);
            return;
        }
        if (command === 'build') {
            await (0, templateLambdaApiBuild_1.buildLambdas)(lambdaRoutes);
            return;
        }
        if (command === 'deploy') {
            await (0, templateLambdaApiDeploy_1.deployCli)(packageConfig.getDeployment(config, opArgs[0]), lambdaRoutes);
            return;
        }
        throw new Error('Unknown command: ' + command);
    });
};
exports.run = run;
//# sourceMappingURL=templateLambdaApi.js.map