"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.deployCli = exports.deployLambdas = void 0;
const infra_aws_1 = require("@goldstack/infra-aws");
const utils_aws_lambda_1 = require("@goldstack/utils-aws-lambda");
const utils_aws_lambda_2 = require("@goldstack/utils-aws-lambda");
const templateLambdaConsts_1 = require("./templateLambdaConsts");
const utils_sh_1 = require("@goldstack/utils-sh");
const templateLambdaApiBuild_1 = require("./templateLambdaApiBuild");
const deployLambdas = async (params) => {
    const lambdaConfig = (0, utils_aws_lambda_2.readLambdaConfig)(templateLambdaConsts_1.defaultRoutesPath);
    const operations = lambdaConfig.map(async (config) => {
        const functionName = (0, utils_aws_lambda_1.generateFunctionName)(params.deployment.configuration.lambdaNamePrefix, config);
        console.log(`[${functionName}]: Starting deployment`);
        const functionDir = (0, templateLambdaApiBuild_1.getOutDirForLambda)(config);
        (0, utils_sh_1.mkdir)('-p', functionDir);
        const targetArchive = `${functionDir}/${config.name}.zip`;
        await (0, utils_aws_lambda_1.deployFunction)({
            targetArchiveName: targetArchive,
            lambdaPackageDir: functionDir,
            awsCredentials: await (0, infra_aws_1.getAWSUser)(params.deployment.awsUser),
            region: params.deployment.awsRegion,
            functionName,
        });
        console.log(`[${functionName}]: Deployment completed`);
    });
    await Promise.all(operations);
};
exports.deployLambdas = deployLambdas;
const deployCli = async (deployment, config) => {
    await (0, exports.deployLambdas)({
        deployment,
        config,
    });
};
exports.deployCli = deployCli;
//# sourceMappingURL=templateLambdaApiDeploy.js.map